pub struct SourcePolicy {
layout: Option<SourceLayoutPolicy>,
adaptation: SourceAdaptationPolicy,
active_speaker: Option<ActiveSpeakerPolicy>,
video_bitrate_cap: Option<Bitrate>,
}Expand description
room policy applied to one published source
SourcePolicy is the source contract between application publish intent
and core room policy
it tells core what it may do with a source after
publish, but it does not name the product feature that created the stream
and it does not limit how many streams a user may publish
Fields
layout: Option<SourceLayoutPolicy>adaptation: SourceAdaptationPolicyactive_speaker: Option<ActiveSpeakerPolicy>video_bitrate_cap: Option<Bitrate>Implementations
Sourceimpl SourcePolicy
impl SourcePolicy
pub const fn new( layout: Option<SourceLayoutPolicy>, adaptation: SourceAdaptationPolicy, active_speaker: Option<ActiveSpeakerPolicy>, ) -> Self
pub const fn with_video_bitrate_cap(self, max_bitrate: Bitrate) -> Self
pub const fn layout(self) -> Option<SourceLayoutPolicy>
pub const fn adaptation(self) -> SourceAdaptationPolicy
pub const fn active_speaker(self) -> Option<ActiveSpeakerPolicy>
pub const fn video_bitrate_cap(self) -> Option<Bitrate>